==> _private_chat-1.3.2.tar.gz: lib/options.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core/theme/option_chat.dart';
import 'package:flutter/material.dart';

PChatOptionsImpl get chatOptions =>
    coreConfig.coreThemes.chatOptions as PChatOptionsImpl;

class PChatOptionsImpl extends PChatOptions {
  Function(TickerProvider)? chatOnInitDetail;
  Function()? chatOnDisposeDetail;

  //Bot options
  bool botEnable;
  String? botThumbnail;
  String? botLabel;
  Future<String?> Function(String)? botGetAnswer;

  //UI chat detail screen
  Widget Function(Widget child, bool isLoadingList, bool isLoadingDetail)?
      chatDetailBackgroundBuilder;
  Widget Function(dynamic state, bool isBot) chatDetailProfileBuilder;
  Widget Function(dynamic state, TextEditingController controller,
      FocusNode node, Function() onSend, bool isBot) chatDetailInputBuilder;

  Widget Function(Widget child, bool isMe) chatMessagePositionBuilder;

  //Message state styles
  bool chatEnableAvatarMessageState;
  TextStyle chatTextStyleMessageState;
  Color? chatIconColorMessageState;

  //Message content styles
  List<Widget> Function(List messages)? chatDetailGroupedMessagesBuilder;
  Widget Function(Widget child, dynamic data, dynamic timestamp)
      chatDetailContentActionBuilder;
  Widget Function(Map data, dynamic indexOfGroup, [String? text])
      chatMessageContentBuilder;

  //Owner infos and messages display
  Widget Function(Widget seenState, String thumbnail, String fullname,
      List<Widget> messages, bool isMe)? chatOwnerBubbleBuilder;

  //Reaction icon display builder
  Widget Function(Widget child, Map reactions, bool isMe)
      chatReactionWrapBuilder;

  PChatOptionsImpl({
    this.botEnable = false,
    this.botGetAnswer,
    this.botLabel,
    this.botThumbnail,
    this.chatOnInitDetail,
    this.chatOnDisposeDetail,
    this.chatDetailBackgroundBuilder,
    required this.chatDetailProfileBuilder,
    required this.chatDetailInputBuilder,
    required this.chatTextStyleMessageState,
    this.chatEnableAvatarMessageState = true,
    this.chatIconColorMessageState,
    this.chatDetailGroupedMessagesBuilder,
    required this.chatDetailContentActionBuilder,
    required this.chatMessageContentBuilder,
    required this.chatMessagePositionBuilder,
    required this.chatOwnerBubbleBuilder,
    required this.chatReactionWrapBuilder,
  });
}

==> _private_chat-1.3.5.tar.gz: lib/options.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core/theme/option_chat.dart';
import 'package:flutter/material.dart';

import '_private_chat.dart';

PChatOptionsImpl get chatOptions =>
    coreConfig.coreThemes.chatOptions as PChatOptionsImpl;

class PChatOptionsImpl extends PChatOptions {
  Function(TickerProvider)? chatOnInitDetail;
  Function()? chatOnDisposeDetail;

  //Bot options
  bool botEnable;
  String? botThumbnail;
  String? botLabel;
  Future<String?> Function(String)? botGetAnswer;

  //UI chat detail screen
  Widget Function(Widget child, bool isLoadingList, bool isLoadingDetail)?
      chatDetailBackgroundBuilder;
  Widget Function(ChatDetailState state, bool isBot) chatDetailProfileBuilder;
  Widget Function(ChatDetailState state, TextEditingController controller,
      FocusNode node, Function() onSend, bool isBot) chatDetailInputBuilder;

  Widget Function(Widget child, bool isMe) chatMessagePositionBuilder;

  //Message state styles
  bool chatEnableAvatarMessageState;
  TextStyle chatTextStyleMessageState;
  Color? chatIconColorMessageState;

  //Message content styles
  List<Widget> Function(List messages)? chatDetailGroupedMessagesBuilder;
  Widget Function(Widget child, dynamic data, dynamic timestamp)
      chatDetailContentActionBuilder;
  Widget Function(Map data, dynamic indexOfGroup, [String? text])
      chatMessageContentBuilder;

  //Owner infos and messages display
  Widget Function(Widget seenState, String thumbnail, String fullname,
      List<Widget> messages, bool isMe)? chatOwnerBubbleBuilder;

  //Reaction icon display builder
  Widget Function(Widget child, Map reactions, bool isMe)
      chatReactionWrapBuilder;

  PChatOptionsImpl({
    this.botEnable = false,
    this.botGetAnswer,
    this.botLabel,
    this.botThumbnail,
    this.chatOnInitDetail,
    this.chatOnDisposeDetail,
    this.chatDetailBackgroundBuilder,
    required this.chatDetailProfileBuilder,
    required this.chatDetailInputBuilder,
    required this.chatTextStyleMessageState,
    this.chatEnableAvatarMessageState = true,
    this.chatIconColorMessageState,
    this.chatDetailGroupedMessagesBuilder,
    required this.chatDetailContentActionBuilder,
    required this.chatMessageContentBuilder,
    required this.chatMessagePositionBuilder,
    required this.chatOwnerBubbleBuilder,
    required this.chatReactionWrapBuilder,
  });
}
